import http from './http';
import type { Machine } from '@/types/Machine';

/**
 * ดึงรายการ Machine ทั้งหมดจาก backend
 */
export async function listMachines(): Promise<Machine[]> {
  const { data } = await http.get('/machines');
  return data;
}

/**
 * ดึงข้อมูล Machine รายการเดียวโดยใช้ MachineID
 */
export async function getMachine(id: number): Promise<Machine> {
  const { data } = await http.get(`/machines/${id}`);
  return data;
}

/**
 * สร้าง Machine ใหม่
 */
export async function createMachine(payload: Partial<Machine>): Promise<Machine> {
  const { data } = await http.post('/machines', payload);
  return data;
}

/**
 * อัปเดต Machine ตาม MachineID
 */
export async function updateMachine(id: number, payload: Partial<Machine>): Promise<Machine> {
  const { data } = await http.put(`/machines/${id}`, payload);
  return data;
}

/**
 * ลบ Machine ตาม MachineID
 */
export async function deleteMachine(id: number): Promise<void> {
  await http.delete(`/machines/${id}`);
}
